﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.IO;

namespace PhotoViewerWeb
{
    public class Album
    {
        private bool exists;
        private Uri source;
        private int count;

        public Album(string path)
            : this(new Uri(path))
        {
        }

        public Album(Uri path)
        {
            if (path == null)
            {
                throw new ArgumentNullException("path");
            }

            try
            {
                if (path.IsFile)
                {
                    this.source = path;
                    this.Refresh();
                }
            }
            catch (InvalidOperationException)
            {
                this.source = null;
                this.Refresh();
            }
        }

        public bool Exists
        {
            get
            {
                return this.exists;
            }
        }

        public Uri Source
        {
            get
            {
                return this.source;
            }
        }

        public string Name
        {
            get
            {
                return Path.GetFileName(this.source.LocalPath);
            }
        }

        public int Count
        {
            get
            {
                return this.count;
            }
        }

        public void Refresh()
        {
            if (this.source != null && Directory.Exists(this.source.LocalPath))
            {
                this.exists = true;
                this.count = Directory.EnumerateFiles(this.source.LocalPath).Count();
            }
            else
            {
                this.exists = false;
                this.count = 0;
            }
        }

        public override string ToString()
        {
            if (this.source != null)
            {
                return this.source.ToString();
            }

            return String.Empty;
        }
    }
}