using System;
using System.Collections.Generic;
using System.Diagnostics.Contracts;
using System.Linq;
using System.Web;
using System.IO;

namespace PhotoViewerWeb
{
    public class Photo
    {
        private bool exists;
        private Uri source;
        private Uri root;

        public Photo(string root, string path)
            : this(new Uri(root), new Uri(path))
        {
        }

        public Photo(Uri root, Uri path)
        {
            Contract.Requires<ArgumentNullException>(root != null);
            Contract.Requires<ArgumentNullException>(path != null);

            this.root = root;

            try
            {
                if (path.IsFile)
                {
                    this.source = path;
                    this.Refresh();
                }
            }
            catch (InvalidOperationException)
            {
                this.source = null;
                this.Refresh();
            }
        }

        public bool Exists
        {
            get
            {
                return this.exists;
            }
        }

        public Uri Source
        {
            get
            {
                return this.source;
            }
        }

        public Uri ImageSource
        {
            get
            {
                return this.root.MakeRelativeUri(this.source);
            }
        }

        public void Refresh()
        {
            if (this.source != null && File.Exists(this.source.LocalPath))
            {
                this.exists = true;
            }
            else
            {
                this.exists = false;
            }
        }

        public override string ToString()
        {
            if (this.source != null)
            {
                return this.source.ToString();
            }

            return String.Empty;
        }
    }
}