﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.IO;
using System.ComponentModel;

namespace PhotoViewerWeb
{
    public class PhotoCollection : ObservableCollection<Photo>
    {
        private DirectoryInfo directoryInfo;
        private string root;
 
        public PhotoCollection(string root, string directory)
            : base()
        {
            if (directory == null)
            {
                throw new ArgumentNullException("directory");
            }

            if (String.IsNullOrWhiteSpace(directory))
            {
                throw new ArgumentException();
            }

            if (root == null)
            {
                throw new ArgumentNullException("root");
            }

            if (String.IsNullOrWhiteSpace(root))
            {
                throw new ArgumentException();
            }

            this.root = root;
            this.Path = System.IO.Path.Combine(root, "Albums", directory);
        }

        public string Path
        {
            get
            {
                return this.directoryInfo.FullName;
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }

                if (String.IsNullOrWhiteSpace(value))
                {
                    throw new ArgumentException();
                }

                this.directoryInfo = new DirectoryInfo(value);
                this.OnPropertyChanged(new PropertyChangedEventArgs("Path"));
                this.Update();
            }
        }

        private void Update()
        {
            this.Clear();
            if (this.directoryInfo.Exists)
            {
                try
                {
                    foreach (FileInfo f in directoryInfo.EnumerateFiles())
                    {
                        Add(new Photo(root, f.FullName));
                    }
                }
                catch (DirectoryNotFoundException)
                {
                    //System.Windows.MessageBox.Show("No Such Directory");
                }
            }
        }
    }
}
